
from django.contrib import admin

from product_barcode.models import BarCode


@admin.register(BarCode)
class BarCodeAdmin(admin.ModelAdmin):

    def has_add_permission(self, request):
        return False

    def has_delete_permission(self, request, obj=None):
        return False




from django.test import TestCase

from product_barcode.models import BarCode


class BarCodeTestCase(TestCase):

    def setUp(self):
        self._barCode = BarCode.objects.create(next_code=10)

    def test_codes_generation(self):

        self.assertEqual(
            BarCode.objects.get().get_next_codes(3),
            ['0000000000109', '0000000000116', '0000000000123']
        )

        self._barCode.next_code = 100
        self._barCode.save()

        self.assertEqual(
            BarCode.objects.get().get_next_codes(3),
            ['0000000001007', '0000000001014', '0000000001021']
        )

        self._barCode.next_code = 1234
        self._barCode.save()

        self.assertEqual(
            BarCode.objects.get().get_next_codes(3),
            ['0000000012348', '0000000012355', '0000000012362']
        )




from django.urls import path, include
from django.conf.urls.i18n import i18n_patterns

from product_barcode import views


app_name = 'barcode'


urlpatterns = [

    path('print/', views.print_codes, name='print'),

    path('img/<str:code>/', views.get_code, name='get'),

    path('generate/', views.generate_codes, name='generate-bar-codes'),

]

app_urls = i18n_patterns(
    path('barcode/', include((urlpatterns, app_name)))
)




from django.utils.translation import ugettext_lazy as _

from cap.filters import InputFilter


class BarCodeFilter(InputFilter):

    parameter_name = 'bar_code'
    title = _('Bar code')

    def queryset(self, request, queryset):

        value = self.value()

        if not value:
            return

        # Fix for old barcodes
        if value.startswith('000') and len(value) == 12:
            value = value[:-1]

        return queryset.filter(bar_code__icontains=value)




from urllib.parse import urlencode

from django.urls import reverse_lazy
from django.shortcuts import render, redirect
from django.utils.translation import ugettext_lazy as _
from django.contrib import messages
from django.contrib import admin
from django.contrib.admin.views.decorators import staff_member_required
from django.http.response import HttpResponse, HttpResponseBadRequest

from product_barcode.models import BarCode


@staff_member_required
def get_code(request, code):

    try:
        img = BarCode.get_image(code)
    except Exception as e:
        messages.error(request, str(e))
        return HttpResponseBadRequest(str(e))

    response = HttpResponse(content_type='image/png')

    img.save(response, 'png')

    return response


@staff_member_required
def print_codes(request):
    extra_str = request.GET.get('extra', '')
    codes_str = request.GET.get('codes', '')
    codes = codes_str.split(',') if codes_str else ''
    return render(request, 'barcode/print.html', {
        'codes': codes,
        'extra_str': extra_str
    })


@staff_member_required
def generate_codes(request):

    context = admin.site.each_context(request)

    if request.method == 'POST':
        try:
            count = int(request.POST['count'])
            codes = BarCode.get_solo().get_next_codes(count)
            url = reverse_lazy('barcode:print')
            url += '?' + urlencode({'codes': ','.join(map(str, codes))})
        except Exception:
            messages.error(request, _('Incorrect number'))
            url = request.path

        return redirect(url)

    return render(request, 'barcode/generate.html', context)
